@@ -12,26 +12,37 @@ with warnings.catch_warnings():
     from .encoders.text.vectorai import *
     from .encoders.text.tf_transformers import *
     from .encoders.text.torch_transformers import *
+    from .encoders.text.sentence_transformers import *
     from .encoders.audio.vectorai import *
     from .encoders.audio.tfhub import *
     from .encoders.audio.pytorch import *
     from .encoders.image.tfhub import *
     from .encoders.image.vectorai import *
+    from .encoders.image.fastai import *
+    from .encoders.face.tf import *
+    from .encoders.code.transformers import *
     from .bi_encoders.text_text.tfhub import *
     from .bi_encoders.text_text.torch_transformers import *
+    from .bi_encoders.text_text.sentence_transformers import *
 
 # Include the class and then the requirements key from models_dict.py
 ENCODER_MAPPINGS = defaultdict(tuple, {
+    # Text models
     Albert2Vec.definition.model_id : (Albert2Vec, "encoders-text-tfhub-albert"),
     Bert2Vec.definition.model_id : (Bert2Vec, "encoders-text-tfhub-bert"),
+    Elmo2Vec.definition.model_id: (Elmo2Vec, "encoders-text-tfhub-elmo"),
     LaBSE2Vec.definition.model_id : (LaBSE2Vec, "encoders-text-tfhub-labse"),
     LegalBert2Vec.definition.model_id: (LegalBert2Vec, "encoders-text-torch-transformers-legalbert"),
+    Longformer2Vec.definition.model_id: (Longformer2Vec, "encoders-text-torch-transformers-longformer"),
     USE2Vec.definition.model_id : (USE2Vec, "encoders-text-tfhub-use"),
     USEMulti2Vec.definition.model_id : (USEMulti2Vec, "encoders-text-tfhub-use"),
     USELite2Vec.definition.model_id : (USELite2Vec, "encoders-text-tfhub-use"),
+    
+
     # "text/tf-transformers" : (TFTransformer2Vec, "encoders-text-tf-transformers"),
     # "text/torch-transformers" : (Transformer2Vec, "encoders-text-torch-transformers"),
 
+    # Audio models
     Wav2Vec.definition.model_id : (Wav2Vec, "encoders-audio-pytorch-fairseq"),
     SpeechEmbedding2Vec.definition.model_id : (SpeechEmbedding2Vec, "encoders-audio-tfhub-speech_embedding"),
     Trill2Vec.definition.model_id : (Trill2Vec, 'encoders-audio-tfhub-trill'),
@@ -39,6 +50,7 @@ ENCODER_MAPPINGS = defaultdict(tuple, {
     Vggish2Vec.definition.model_id : (Vggish2Vec, 'encoders-audio-tfhub-vggish'),
     Yamnet2Vec.definition.model_id : (Yamnet2Vec, "encoders-audio-tfhub-vggish"),
 
+    # Image models
     BitSmall2Vec.definition.model_id : (BitSmall2Vec, "encoders-image-tfhub-bit"),
     BitMedium2Vec.definition.model_id : (BitMedium2Vec, "encoders-image-tfhub-bit"),
     InceptionV12Vec.definition.model_id : (InceptionV12Vec, "encoders-image-tfhub-inception"),
@@ -48,7 +60,14 @@ ENCODER_MAPPINGS = defaultdict(tuple, {
     MobileNetV12Vec.definition.model_id : (MobileNetV12Vec, "encoders-image-tfhub-mobilenet"),
     MobileNetV22Vec.definition.model_id : (MobileNetV22Vec, "encoders-image-tfhub-mobilenet"),
     ResnetV12Vec.definition.model_id : (ResnetV12Vec, "encoders-image-tfhub-resnet"),
-    ResnetV22Vec.definition.model_id : (ResnetV22Vec, "encoders-image-tfhub-resnet")
+    ResnetV22Vec.definition.model_id : (ResnetV22Vec, "encoders-image-tfhub-resnet"),
+    FastAIResnet2Vec.definition.model_id: (FastAIResnet2Vec, "encoders-image-fastai-resnet"),
+
+    # Face Model
+    Face2Vec.definition.model_id: (Face2Vec, "encoders-image-tf-face-detection"),
+
+    # Code model 
+    Code2Vec.definition.model_id: (Code2Vec, "encoders-text-tranfsormers"),
 })
 
 class AutoEncoder:
