@@ -2,6 +2,8 @@ import functools
 import warnings
 import traceback
 import numpy as np
+import requests
+from .indexer import ViIndexer
 from .errors import ModelError
 from typing import Any, List
 from abc import ABC, abstractmethod
@@ -47,7 +49,7 @@ def catch_vector_errors(func):
                 return [1e-7] * vector_length
     return catch_vector
 
-class Base2Vec:
+class Base2Vec(ViIndexer):
     """
         Base class for vector
     """
@@ -57,13 +59,37 @@ class Base2Vec:
     @classmethod
     def validate_model_url(cls, model_url: str, list_of_urls: List[str]):
         """
-            Validate the model url belongs in the list of urls.
+            Validate the model url belongs in the list of urls. This is to help
+            users to avoid mis-spelling the name of the model.
+
+            # TODO:
+            Improve model URL validation to not include final number in URl string.
+
+            Args:
+                model_url: The URl of the the model in question
+                list_of_urls: The list of URLS for the model in question
+
         """
-        if(model_url in list_of_urls):
+        if model_url in list_of_urls:
             return True
-        raise ModelError(
-            message="We currently not support this url. If issue persist then contact us.")
-            
+
+        if 'tfhub' in model_url:
+            # If the url has a number in it then we can take that into account
+            for url in list_of_urls:
+                if model_url[:-1] in url:
+                    return True
+        # TODO: Write documentation link to debugging the Model URL.
+        warnings.warn("We have not tested this url. Please use URL at your own risk." + \
+            "Please use the is_url_working method to test if this is a working url if " + \
+            "this is not a local directory.", UserWarning)
+
+    @staticmethod
+    def is_url_working(url):
+        response = requests.head(url)
+        if response.status_code == 200:
+            return True
+        return False
+
     @classmethod
     def chunk(self, lst: List, chunk_size: int):
         """
@@ -83,7 +109,7 @@ class Base2Vec:
     def _vector_operation(self, vectors, vector_operation: str = "mean", axis=0):
         """
             Args:
-                Vectors: the list of vectors to include 
+                Vectors: the list of vectors to include
                 vector_operation: One of ['mean', 'minus', 'sum', 'min', 'max']
                 axis: The axis to which to perform the operation
         """
@@ -98,4 +124,37 @@ class Base2Vec:
         elif vector_operation == "max":
             return np.max(vectors, axis=axis).tolist()
         else:
-            return np.mean(vectors, axis=axis).tolist()
\ No newline at end of file
+            return np.mean(vectors, axis=axis).tolist()
+
+    @property
+    def __name__(self):
+        """
+            Return the name of the model. If name is not set, returns the
+            model_id.
+        """
+        if hasattr(self, '_name'):
+            return self._name
+        elif hasattr(self, 'definition'):
+            if '/' in self.definition.model_id:
+                return self.definition.model_id.split('/')[1]
+            return self.definition.model_id
+        return ''
+
+    @__name__.setter
+    def __name__(self, value):
+        """
+            Set the name.
+        """
+        setattr(self, '_name', value)
+
+    def add_to_vectorai(self, words, metadata, username, api_key):
+        """
+        """
+        self.insert_documents()
+
+    def add_to_annoy(self):
+        raise NotImplementedError
+
+    def add_to_hnsw(self):
+        raise NotImplementedError
+
